@@ -9,11 +9,15 @@
 # Some parameters of the dense algorithm are set according to my experience and should be OK
 # for most cases. However, they are only tested for sparse design matrices up to the order
 # ~ 90.000x2.900
-# Output: p1 : parameter estimations of factor 1 (year effects)
-# 		  p2 : parameter estimations of factor 2 (station effects)
-#		  resid : residuals
-#		  ierr : return code of the l1 estimation
-#		  D  : the input as ordered data frame, ordered first after f2 then f1
+# Output: 
+#	f1 : parameter estimations of factor 1 (year effects)
+#	f1.lev : levels of first factor
+#	f2 : parameter estimations of factor 2 (station effects)
+#	f2.lev : levels of second factor
+#	resid : residuals
+#	ierr : return code of the l1 estimation
+#	D  : the input as ordered data frame, ordered first after f2 then f1
+#	fit  : rq.fit object
 pheno.lad.fit <- function(D) {
 	if(!is.data.frame(D) && !is.matrix(D)) {
 		stop("lad.fit: argument must be data frame with 3 columns or matrix")
@@ -27,29 +31,33 @@ pheno.lad.fit <- function(D) {
 
 	D <-  D[order(D[[3]],D[[2]]),]
 
-	s <- factor(D[[3]])
-	y <- factor(D[[2]])
-	o <- as.vector(D[[1]],"numeric")
-	nobs <- length(o)
-
-	if(nobs > 1000) { # sparse matrix implementation
+	if(length(D[[1]]) > 1000) { # sparse matrix implementation
 		S <- pheno.ddm(D)
+		s <- factor(S$D[[3]])
+		y <- factor(S$D[[2]])
+		o <- as.vector(S$D[[1]],"numeric")
+		nobs <- length(o)
 		m <- S$ddm@dimension[2]
-	    nnzdmax <- S$ddm@ia[nobs + 1] - 1
-		l1fit <- rq.fit.sfn(S$ddm,o,tau=0.5,tmpmax=1000*m,nnzlmax=100*nnzdmax,small=1e-04)
+	    	nnzdmax <- S$ddm@ia[nobs + 1] - 1
+		l1fit <- rq.fit.sfn(S$ddm,o,tau=0.5,tmpmax=1000*m,nnzlmax=100*nnzdmax,small=1e-06)
 		p1 <- as.vector(l1fit$coef[1:nlevels(y)],"numeric")
 		p2 <- as.vector(contr.sum(nlevels(s)) %*% l1fit$coef[(nlevels(y)+1):(nlevels(y)+nlevels(s)-1)],"numeric")
 		resid <- S$D[[1]] - l1fit$coef[match(y,levels(y))]
 		ierr <- l1fit$ierr 
 	}
-	else {			# normal fit
+	else {		# normal fit
 		
-		ddm <- as.matrix.csr(model.matrix(~ y + s -1, contrasts=list(s=("contr.sum"))))
+		s <- factor(D[[3]])
+		y <- factor(D[[2]])
+		o <- as.vector(D[[1]],"numeric")
+		nobs <- length(o)
+
+		ddm <- as.matrix.csr(model.matrix(~ y + s - 1, contrasts=list(s=("contr.sum"))))
 		l1fit <- rq.fit(ddm,o,tau=0.5,method="br")
 		p1 <-  as.vector(l1fit$coef[1:nlevels(y)],"numeric")
 		p2 <- as.vector(contr.sum(nlevels(s)) %*% l1fit$coef[(nlevels(y)+1):(nlevels(y)+nlevels(s)-1)],"numeric")
 		resid <- as.vector(residuals(l1fit),"numeric")
 		ierr <- NA
 	}
-	return(list(p1=p1, p2=p2, resid=resid, ierr=ierr, D=D))
+	return(list(f1=p1,f1.lev=levels(y),f2=p2,f2.lev=levels(s),resid=resid,ierr=ierr,D=D,fit=l1fit))
 }
